==> deculture-0.0.0-src.zip: deculture/java/src/net/morilib/deculture/translate/y.tab.java.sh <==
echo '// Translated by Deculture'
echo '// This source code is under public domain'
cat definition

cat << EOF

public class ${CLASSNAME} {

	//
	private static final Object ENDMARKER = new Object();
	private static final int INITSIZE = 765;
	private static final String __ERROR = "";

	//
	private int __stateID;
	private Object[] __synarray = new Object[INITSIZE];
	private int __synptr;
	private Object __lookahead = null;
	private java.util.Iterator<Object> __lexer;

	//
	private ${CLASSNAME}() {
		__stateID = ${INIT_STATE_ID};
		__synarray[0] = __stateID;
		__synptr = 1;
	}

EOF

cat fragment

echo '	private int getShift(Object __c) {'
echo '		Object __t;'
echo '		switch(__stateID) {'
put_shift
echo '		}'
echo '		return -1;'
echo '	}'
echo

echo '	private int getReduce(Object __c) {'
echo '		Object $$, __t;'
echo '		int __k;'
echo
echo '		switch(__stateID) {'
put_reduce
echo '		}'
echo '		return -1;'
echo '	}'
echo

echo '	private boolean isAccept(Object __c) {'
echo '		Object __t;'
echo '		switch(__stateID) {'
put_accept
echo '		}'
echo '		return false;'
echo '	}'
echo

echo '	private static int getGoto(int __stateID, int __n) {'
echo '		switch(__stateID) {'
put_goto
echo '		}'
echo '		throw new RuntimeException();'
echo '	}'
echo

cat << EOF
	private Object _next() {
		return __lexer.hasNext() ? __lexer.next() : ENDMARKER;
	}

	private static boolean __end(Object o) {
		return o == ENDMARKER;
	}

	private static boolean __eq(Object o, Object p) {
		return o.equals(p);
	}

	private static boolean __eq(Object o, int p) {
		return o.equals(Character.valueOf((char)p));
	}

	private void _push(int k, Object s) {
		Object[] a;

		if(__synptr >= __synarray.length) {
			a = new Object[INITSIZE * 2 + 1];
			System.arraycopy(__synarray, 0, a, 0, __synarray.length);
			__synarray = a;
		}
		__synarray[__synptr++] = s;
		__synarray[__synptr++] = k;
	}

	private void _pop(int num) {
		if(__synptr < num * 2)  throw new RuntimeException();
		__synptr -= num * 2;
	}

	private int _refsyn() {
		return ((Integer)__synarray[__synptr - 1]).intValue();
	}

	private Object _refv(int n) {
		return __synarray[__synptr - n * 2];
	}

	public static Object parse(java.util.Iterator<Object> lexer) {
		${CLASSNAME} p = new ${CLASSNAME}();
		boolean err = false;
		Object x;
		int k;

		p.__lexer = lexer;
		while(true) {
			if(err) {
				if((k = p.getShift(p.__lookahead)) >= 0) {
					p._push(k, p.__lookahead);
					p.__stateID = k;
					err = false;
				} else if((p.__lookahead = p._next()) == ENDMARKER) {
					throw new RuntimeException();
				}
			} else {
				if(p.isAccept(null)) {
					return p._refv(1);
				} else if((k = p.getShift(null)) >= 0) {
					p._push(k, p.__lookahead);
					p.__lookahead = null;
					p.__stateID = k;
				} else if((k = p.getReduce(null)) >= 0) {
					p.__stateID = k;
				} else if(p.__lookahead == ENDMARKER) {
					throw new RuntimeException();
				} else {
					while(p.getShift(__ERROR) < 0) {
						p._pop(1);
						p.__stateID = ((Integer)p.__synarray[p.__synptr - 1]).intValue();
					}
					p.__stateID = p.getShift(__ERROR);
					p._push(k, __ERROR);
					err = true;
				}
			}
		}
	}

EOF
echo '}'

==> deculture-0.0.1-src.zip: deculture/java/src/net/morilib/deculture/translate/y.tab.java.sh <==
echo '// Translated by Deculture'
echo '// This source code is under public domain'
cat definition

cat << EOF

public class ${CLASSNAME} {

	//
	private static final Object ENDMARKER = new Object();
	private static final int INITSIZE = 765;
	private static final Object __ERROR = new Object();

	//
	private int __stateID;
	private Object[] __synarray = new Object[INITSIZE];
	private int __synptr;
	private Object __lookahead = null;
	private java.util.Iterator<Object> __lexer;

	//
	private ${CLASSNAME}() {
		__stateID = ${INIT_STATE_ID};
		__synarray[0] = __stateID;
		__synptr = 1;
	}

	static interface StateAction {
		public int getShiftState(Object __c);
		public int getReduceState(Object __c);
		public boolean isAcceptState(Object __c);
		public int getGotoState(int __stateID, int __n);
	}

	public static class ParseException extends RuntimeException {
	}
EOF

cat fragment

for num in `put_states`
do
echo "	private StateAction ACTION_${num} = new StateAction() {"
echo '	public int getShiftState(Object __c) {'
echo '		Object __t;'
put_shift ${num}
echo '	}'
echo

echo '	public int getReduceState(Object __c) {'
echo '		Object $$, __t;'
echo '		int __k;'
echo
put_reduce ${num}
echo '	}'
echo

echo '	public boolean isAcceptState(Object __c) {'
echo '		Object __t;'
put_accept ${num}
echo '	}'
echo

echo '	public int getGotoState(int __stateID, int __n) {'
put_goto ${num}
echo '	}'
echo '	};'
echo
done

echo '	private StateAction[] ACTION_TABLE = new StateAction[] {'
for num in `put_states`
do
  echo "		ACTION_${num},"
done
echo '	};'

cat << EOF
	private int getShift(Object __c) {
		if(__stateID < ACTION_TABLE.length) {
			return ACTION_TABLE[__stateID].getShiftState(__c);
		} else {
			return -1;
		}
	}

	private int getReduce(Object __c) {
		if(__stateID < ACTION_TABLE.length) {
			return ACTION_TABLE[__stateID].getReduceState(__c);
		} else {
			return -1;
		}
	}

	private boolean isAccept(Object __c) {
		if(__stateID < ACTION_TABLE.length) {
			return ACTION_TABLE[__stateID].isAcceptState(__c);
		} else {
			return false;
		}
	}

	private int getGoto(int __stateID, int __n) {
		if(__stateID < ACTION_TABLE.length) {
			return ACTION_TABLE[__stateID].getGotoState(__stateID, __n);
		} else {
			throw new RuntimeException();
		}
	}

	private Object _next() {
		return __lexer.hasNext() ? __lexer.next() : ENDMARKER;
	}

	private static boolean __end(Object o) {
		return o == ENDMARKER;
	}

	private static boolean __eq(Object o, Object p) {
		return o.equals(p);
	}

	private static boolean __eq(Object o, int p) {
		return o.equals(Character.valueOf((char)p));
	}

	private void _push(int k, Object s) {
		Object[] a;

		if(__synptr >= __synarray.length) {
			a = new Object[INITSIZE * 2 + 1];
			System.arraycopy(__synarray, 0, a, 0, __synarray.length);
			__synarray = a;
		}
		__synarray[__synptr++] = s;
		__synarray[__synptr++] = k;
	}

	private void _pop(int num) {
		if(__synptr < num * 2)  throw new RuntimeException();
		__synptr -= num * 2;
	}

	private int _refsyn() {
		return ((Integer)__synarray[__synptr - 1]).intValue();
	}

	private Object _refv(int n) {
		return __synarray[__synptr - n * 2];
	}

	public static Object parse(java.util.Iterator<Object> lexer) {
		${CLASSNAME} p = new ${CLASSNAME}();
		boolean err = false;
		Object x;
		int k;

		p.__lexer = lexer;
		while(true) {
			if(err) {
				if((k = p.getShift(p.__lookahead)) >= 0) {
					p._push(k, p.__lookahead);
					p.__stateID = k;
					err = false;
				} else if((p.__lookahead = p._next()) == ENDMARKER) {
					throw new ParseException();
				}
			} else {
				if(p.isAccept(null)) {
					return p._refv(1);
				} else if((k = p.getShift(null)) >= 0) {
					p._push(k, p.__lookahead);
					p.__lookahead = null;
					p.__stateID = k;
				} else if((k = p.getReduce(null)) >= 0) {
					p.__stateID = k;
				} else if(p.__lookahead == ENDMARKER) {
					throw new ParseException();
				} else {
					while(p.getShift(__ERROR) < 0) {
						if(p.__synptr <= 1) {
							throw new ParseException();
						}
						p._pop(1);
						p.__stateID = ((Integer)p.__synarray[p.__synptr - 1]).intValue();
					}
					p.__stateID = p.getShift(__ERROR);
					p._push(k, __ERROR);
					err = true;
				}
			}
		}
	}

EOF
echo '}'
